<# 

PowerShell Survival Guide
Datacentre Ailift
2016-11-28
(C) 2016, Andre Melancia and Ricardo Cabral

02-Learn Powershell Basics
Version: 0.4 Public Release
#>


<# 
+----------------------------------------------------------------+
| Variables                                                      |
+----------------------------------------------------------------+
#>

<# Variables #>

$Var1 = "Datacentre Airlift, p!"
$Var1             <# Prints variable       #>
Write-Host $Var1  <# Also prints variable! #>
Write-Host $vAR1  <# Case insensitive, p! #>
Get-Variable Var1 <# Still another way     #>


New-Variable -Name OtherVariable  -Value "Outra varivel, p!"  
Write-Host $OtherVariable  
$OtherVariable = "Alterado"
Write-Host $OtherVariable  


Clear
Get-Variable | Select Name, Value | Select-String "Var"

Remove-Variable -Name OtherVariable
Remove-Variable -Name Var1

Get-Variable | Select Name, Value | Select-String "Var"

[int] $Var2 = 123;
[int] $Var3 = 543;
$Var2 + $Var3



<# Scopes #>

$test = "Global Scope"

Function Foo {
    $test = 'Function Scope'
    Write-Host $Global:test                                  # Global Scope
    Write-Host $Local:test                                   # Function Scope
    Write-Host (Get-Variable -Name test -ValueOnly -Scope 0) # Function Scope
    Write-Host (Get-Variable -Name test -ValueOnly -Scope 1) # Global Scope
}
Foo


<# Arrays #>

$array = @("a", "b")

Write-Host $array

$array += "c"

Write-Host $array


<# 
+----------------------------------------------------------------+
|  Modules Instalation                                           |
|  Warning Administrator Rights Are Required                     | 
+----------------------------------------------------------------+
#>

# Install the Azure Resource Manager (AzureRM) modules from the PowerShell Gallery
Install-Module AzureRM


# Install the Azure Service Management (Azure) module from the PowerShell Gallery
Install-Module Azure

# Force install lower version
Install-module Azure -MinimumVersion 0.8.10 -Force 


# Install Module for current user
Install-Module Azure -Scope CurrentUser

<# 
+----------------------------------------------------------------+
|  Example of Installing Powershell Modules For Selected Azure   |
|  Services                                                      |
+----------------------------------------------------------------+
#>

# Azure storage tools & Azure regions in CIDR format 
Install-Module AzureStorageTools                  
Install-Module AzurePublicIPAddresses

# Microsoft Azure Service Management core
Install-Module AzureExt

#DSC Resources
Install-Module xAzure
Install-Module cAzureStorage

#Azure AD
Install-Module AzureAD
Install-Module Avanade.AzureAD    

# Powershell commands to manage Azure Virtual Machines  
Install-Module Azure.ToolKit 

# Miscellaneous tools for Azure Resource Manager
Install-Module AzureRmMinus 

# AzureRM Compute and Storage
Install-Module AzureRM.Compute
Install-Module AzureRM.Storage

# Migrates Azure Classic Virtual Networks, and all dependent resources to Resource Manager.
Install-Module MigrateTo-AzureRM

<# 
+----------------------------------------------------------------+
|  Modules List, Search, Import, Commands And Uninstall          |
+----------------------------------------------------------------+
#>

# -- List installed Modules --
Get-Module
Get-Module -list
Get-Module ListAvailable AzureRM*

#-- Where modules are installed --
dir 'c:\Program Files\WindowsPowerShell\Modules\'
ls 'c:\Program Files\WindowsPowerShell\Modules\'
Get-ChildItem -Path 'c:\Program Files\WindowsPowerShell\Modules\'
Get-ChildItem -Path 'c:\Program Files\WindowsPowerShell\Modules\' -Recurse -File | sort length Descending

# -- Search modules --
Find-Module *AzureRM*
Find-Module -tag Compute

# -- Import Modules --
Import-Module AzureRM.Compute
Import-Module AzureRM.Storage

# -- Module Commands --
Get-Command -Module AzureRM.Compute

# -- Uninstall Module --
Uninstall-Module AzureExt

<#
+----------------------------------------------------------------+
|  Compatible Commands            |                              |
+----------------------------------------------------------------+
#>

# -- MicroSoft Disk Operating System (MD-DOS) commands line are compatible --
cls  
echo  "Hello Airlift " 
MD    c:\tempAE\HELLO_WORLD
MKDIR c:\tempAE\HELLO_WORLD2
RD    c:\tempAE\HELLO_WORLD
RMDIR c:\tempAE\HELLO_WORLD2
DIR   c:\tempAE\

# -- Linux Commands --
clear
echo     "Hello Airlift"
mkdir -p c:\tempAE\HELLO_WORLD
rmdir    c:\tempAE\
ls       c:\tempAE\

# -- Powershell commands --
Clear-Host
Write-Host  "Hello Airlift " 
New-Item    "c:\tempAE\HELLO_WORLD" -Type Directory
Remove-Item -Recurse -Force  "c:\tempAE\"
Get-ChildItem c:\tempAE\

# -- Example with files --

New-Item "c:\tempAE\" -Type Directory
New-Item "c:\tempAE\Txt.txt"  -Type File
Get-Content "c:\tempAE\Txt.txt"


<#  HELP #>

Get-Help ls
man ls

Get-Help ls -Detailed
Get-Help ls -Examples
Get-Help ls -Full

Get-Command -Module AzureRM.Compute | Get-Help | Format-Table Name, Synopsis

<# Alias #>

# -- View all Alias --
Get-Alias 

# --  Create and remove Alaias --
Set-Alias uname Get-WmiObject

uname -class Win32_OperatingSystem 

Remove-Item alias:uname

uname


<# 
+----------------------------------------------------------------+
| Command line history from current session                      |
+----------------------------------------------------------------+
#>
Get-History
Get-History -count 5

# -- Clean history
Clear-History

# -- Save history --
get-history | export-csv c:\temp\history.csv 
import-csv c:\temp\history.csv  | add-history
Get-History

<#
+----------------------------------------------------------------+
| Functions                                                      |
+----------------------------------------------------------------+
#>

function TempText { dir C:\temp\*.txt }

TempText

# -- Functions with parameters -- 

function foo($a, $b, $c) {
   "a: $a;      b: $b;     c: $c"
}

 foo 1 2 3