<# 

PowerShell Survival Guide
Datacentre Ailift
2016-11-28
(C) 2016, Andre Melancia and Ricardo Cabral

03-Adminstrator Windows Server 2016 with PowerShell
Version: 0.3
#>


<# 
+----------------------------------------------------------------+
| Azure Virtual Machine Settings                                 |
+----------------------------------------------------------------+
 #>

cls
$username = "Insert VM Administrator Account"
$VMName = "Insert Azure Virtual Machine Name"
$Locantion = "Insert The Location For URI ex. northeurope"
$VMAdress = $VMName + "." + $Locantion ".cloudapp.azure.com"



# --- View VM Public IP
$VMIP = [System.Net.Dns]::GetHostAddresses($VMAdress).IPAddressToString
Write-Host $VMIP

<# 
+----------------------------------------------------------------+
| Settings Active Directory Domain Services                      |
| If You Whant To Change The Domain Name Change The Script       |
| Session 'Active Directory Domain Services' and                 |
| 'Active Directory Operations'                                  |
+----------------------------------------------------------------+
#>

$domain = "Airlift"

<# 
+----------------------------------------------------------------+
| WinRM                                                          |
+----------------------------------------------------------------+
#>
 
# -- WinRM 2.0: 5985[HTTP]  5986[HTTPS] --
Set-ExecutionPolicy RemoteSigned
Enable-PSRemoting -Force
Set-Item wsman:\localhost\client\trustedhosts $VMAdress
Restart-Service WinRM
Test-WsMan -ComputerName $VMAdress

# --- HTTP Session Local Account
Enter-PSSession -ComputerName $VMAdress -Credential $username


# --- HTTP Session Local Domain Account
Enter-PSSession -ComputerName $VMAdress -Credential $domain\$username

# --- HTTPS Session Local Account ----

Enter-PSSession -ComputerName $VMAdress -Credential $username UseSSL

# -- Inside Network -- 
Set-ExecutionPolicy RemoteSigned
Enable-PSRemoting -Force
Set-Item wsman:\localhost\client\trustedhosts $VMIP
Restart-Service WinRM
Enter-PSSession $VMIP

<#
+----------------------------------------------------------------+
| Retrieving Process Information                                 |
+----------------------------------------------------------------+
#>

Get-Process
Get-Process | Format-Table -AutoSize


<# Windows Feature #>
Get-WindowsFeature
Get-WindowsFeature Ad*
Get-WindowsFeature *Hyper-V*

# Install-WindowsFeature
# Uninstall-WindowsFeature

<#
+----------------------------------------------------------------+
|  Active Directory Domain Services                              |
+----------------------------------------------------------------+
#>

#-- Install Active Directory Domain Services Forest --

<# Testing Before Install#>
Install-windowsfeature -name AD-Domain-Services -IncludeManagementTools   
Test-ADDSForestInstallation -DomainName airlift.local -DomainNetbiosName airlift1

<# Then Install #>
Set-ExecutionPolicy RemoteSigned
Import-Module ADDSDeployment
<# 
Example from Microsoft:
Install-ADDSDomainController -NoGlobalCatalog:$false -InstallDns:$false -CreateDnsDelegation:$false -CriticalReplicationOnly:$false -DatabasePath "C:\Windows\NTDS" -LogPath "C:\Windows\NTDS" -SysvolPath "C:\Windows\SYSVOL" -DomainName "contoso.local" -NoRebootOnCompletion:$false -SiteName "SiteName" -Force:$true
#>
Install-ADDSForest -DatabasePath "C:\Windows\NTDS" -DomainMode "Win2012R2" -DomainName "airlift.local" -DomainNetBIOSName "airliftl" -ForestMode "Win2012R2" -InstallDNS:$true -LogPath "C:\Windows\NTDS" -NoRebootOnCompletion:$false -SYSVOLPath "C:\Windows\SYSVOL" -Force:$true

# -- Forest Informacion -- 
[System.DirectoryServices.ActiveDirectory.Forest ]::GetCurrentForest()

<# 
Install Domain in Forest. First Testing Before install:
Test-ADDSDomainInstallation -NewDomainName training.airlift.local  -NewDomainNetbiosName airliftl -ParentDomainName airlift.local  
Test-ADDSDomainControllerInstallation -DomainName airlift.local
Then Install :
Import-Module ADDSDeployment 
Install-ADDSDomainController -DomainName airlift.local
#>


<# 
+----------------------------------------------------------------+
|  Active Directory Operations                                   |
+----------------------------------------------------------------+
#>

# -- New Organizational Unit --
New-ADOrganizationalUnit -Name TestUsers -Path "DC=airlift,DC=local" -ProtectedFromAccidentalDeletion $false
# Remove-ADOrganizationalUnit -Identity "OU=TestUsers,DC=airlift,DC=local" -confirm:$true

# -- List all ADOrganizationalUnit --
cls
Get-ADOrganizationalUnit -Filter * -Properties CanonicalName | Select-Object -Property CanonicalName
Get-ADObject -Filter { ObjectClass -eq 'organizationalunit' }

# -- New AD User --
$UserPassword = ConvertTo-SecureString -String  "P@SSw0rd"  -AsPlainText -Force
New-ADUser -Name "User Test" -GivenName User -Surname Test -SamAccountName usertest -UserPrincipalName usertest@airlift.local -Company "Island Tropical" -Organization "Testing AD" -Department "Testing" -ChangePasswordAtLogon 1 -AccountPassword $UserPassword 
# Remove-ADUser usertest

# -- Move User to new Organizational Unit --
Move-ADObject 'CN=User Test,CN=Users,DC=airlift,DC=local' -TargetPath 'OU=TestUsers,DC=airlift,DC=local'

# -- List all users --
Get-ADOrganizationalUnit -SearchBase 'OU=TestUsers,DC=airlift,DC=local' -SearchScope Subtree -Filter * | Select-Object DistinguishedName, Name


<# 
+----------------------------------------------------------------+
|  Windows PowerShell Desired State Configuration (DSC)          |
+----------------------------------------------------------------+
#>

# -- Install Modules --
Install-Module xActiveDirectory
Install-Module xWebAdministration
Install-Module xNetworking
Install-Module NTFSSecurity

# -- Import Modules --
Import-Module xActiveDirectory
Import-Module xWebAdministration
Import-Module xNetworking
Import-Module NTFSSecurity

# -- Verefy Modules Instalation --
Get-DscResource | select Name,Module,Properties | Ft -AutoSize

#-- Start-DscConfiguration
#-- Get-DscConfiguration

# Upload the file to server [Warning: Open a new PowerShell session/window]

# (This Session)
Remove-Item -Recurse -Force  "C:\airlift"
New-Item "C:\airlift" -Type Directory
ls "C:\airlift"

# (New Session)
$VMName ="airlift.northeurope.cloudapp.azure.com"
$pssession = New-PSSession -ComputerName $VMName -Credential "itpro" 
Enter-PSSession -Session $s
Copy-Item -ToSession $pssession -Path ".\03a-ISSTest-DSC.PS1" -Destination "c:\airlift"


# Return to preview session/window and execute .\03a-ISSTest-DSC.PS1

ls "C:\airlift"
c:\airlift\03a-ISSTest-DSC.PS1 MachineName Airlift Wait Verbose
Get-DSCResource File -syntax

	
ContosoWebsite MachineName Airlift
Start-DscConfiguration Path .\ContosoWebsite Wait Verbose


Get-WindowsFeature *Web-Server*


Get-DSCLocalConfigurationManager

<# 
+----------------------------------------------------------------+
|  Verify Installed Windows Package                              |
+----------------------------------------------------------------+
#>
Get-WindowsPackage -Online 
Get-WindowsPackage -Online | Where-Object {$_.PackageName -like "*Fix*"}
#Add-WindowsPackage


<# Connect Virtual Machine By RDP#>
mstsc /f /v:$VMIP