﻿<# 

PowerShell Survival Guide
Datacentre Ailift
2016-11-28
(C) 2016, Andre Melancia and Ricardo Cabral

04-Azure PowerShell
Version: 0.4 Public Release
#>


<# 
+----------------------------------------------------------------+
|  install Modules                                               |
+----------------------------------------------------------------+
#>

Install-Module Azure​RM
Install-Module Azure​

<#
+----------------------------------------------------------------+
|  Azure Account                                                 |
+----------------------------------------------------------------+
#>

# -- Add Azure RM Account in computer --
Add-AzureRmAccount

# -- Login AzureRM --
#Login-AzureRmAccount

# -- List all Azure Subscriptions -- 
Get-AzureRmSubscription

# -- Select a Subscription-- 
$SubscriptionId = "Change To Your Account ID"

Select-AzureRmSubscription -SubscriptionId $SubscriptionId 
Get-AzureRmSubscriptionMenu

<#
+----------------------------------------------------------------+
|  Azure Settings                                                |
+----------------------------------------------------------------+
#>

$AzureLocation = "North Europe" 
$RGName = "Insert a Name For Resoure Group"
$WebAppName = "Insert Name for WebApp. Please dont use Caps Lock"
$WebAppTDName = "Insert Name for WebApp Deployed By ARM Template. Please dont use Caps Lock"
$SAccountName = "Insert Name for Storage Account.Please dont use Caps Lock"
$VMName = "Insert Virtual Machine Name"

<#
+----------------------------------------------------------------+
|  Azure Resource Group                                          |
+----------------------------------------------------------------+
#>


# -- Create a new Resource Group --
New-AzureRmResourceGroup -Name $RGName -Location $AzureLocation -Tag @{Name="Event";Value="Data center Airlift"} -Verbose

# -- View the resource Group created --
Get-AzureRmResourceGroup $RGName

# -- Search Resource Group --
Find-AzureRmResource -ResourceNameContains $RGName
Find-AzureRmResource -TagName "*"+ $RGName + "*"

# -- Delete resource Group --
Remove-AzureRmResourceGroup -Name $RGName

<#
+----------------------------------------------------------------+
|  Azure WebApp                                                  |
+----------------------------------------------------------------+
#>

# -- Create new App Service plan -- 
<#
Free Tier will be used
https://azure.microsoft.com/en-us/pricing/details/app-service/plans/
#>
 New-AzureRmAppServicePlan -Name DCAWebAppF1 -Tier Free -ResourceGroupName $RGName -Location $AzureLocation

# -- View App Service plan --
Get-AzureRmAppServicePlan -Name DCAWebAppF1 

# -- New Deploy WebApp --
New-AzureRmWebApp -Name $WebAppName -ResourceGroupName $RGName -AppServicePlan DCAWebAppF1 -Location $AzureLocation -Verbose

# -- WebApp Informacion --
Get-AzureRmWebApp -Name $WebAppName -ResourceGroupName $RGName| select Name,HostNames,State | Ft -AutoSize

[System.Diagnostics.Process]::Start("iexplore","https://" + $WebAppName +".azurewebsites.net")

# -- Star and stop WebApp --
Start-AzureRmWebApp -Name $WebAppName  -ResourceGroupName $RGName -Verbose
Stop-AzureRmWebApp -Name $WebAppName -ResourceGroupName $RGName -Verbose

# -- Deploy Template + GitHub --
New-AzureRmResourceGroupDeployment -TemplateUri https://raw.githubusercontent.com/Azure/azure-quickstart-templates/master/201-web-app-github-deploy/azuredeploy.json -siteName $WebAppTDName  -hostingPlanName DCAWebAppF1 -sku F1  -ResourceGroupName $RGName -Verbose

[System.Diagnostics.Process]::Start("iexplore","https://"+ $WebAppTDName + ".azurewebsites.net")

<#
+----------------------------------------------------------------+
|  Azure Storage                                                 |
+----------------------------------------------------------------+
#>

# -- Verefy availability of a storage account name --
Get-AzureRmStorageAccountNameAvailability -Name $SAccountName 

# -- New Storage Account --
New-AzureRmStorageAccount -StorageAccountName $SAccountName -ResourceGroupName $RGName -SkuName Standard_ZRS -Location $AzureLocation -Verbose

# -- View storage accounts creation time --
Get-AzureRmStorageAccount -ResourceGroupName $RGName -Name $SAccountName | Select-Object StorageAccountName,CreationTime

# -- Total GBs used in storage --
Get-AzureRmStorageAccount -ResourceGroupName $RGName -Name $SAccountName | Get-AzureStorageContainer | Get-AzureStorageBlob | Measure-Object Length -Sum | select-object sum
$TotalGB = $A.Sum/1024/1024/1024
Write-Host $TotalGB "GB"


# -- Get storage key and create new Shared access signature context --
$storageKey = (Get-AzureRmStorageAccountKey -StorageAccountName $SAccountName -ResourceGroup $RGName).Value[0]
$saContext = New-AzureStorageContext -StorageAccountName $SAccountName  -StorageAccountKey $storagekey
$sourceVhdContainer = "images"

# -- Create container --
New-AzureStorageContainer -Context $saContext -Name data -Verbose

# -- View container
Get-AzureStorageContainer -Name data -Context $saContext

# -- Upload file to container -- 
Set-AzureStorageBlobContent -Container data -Context $saContext -File ".\MSFTDXPortugal.jpg"

# -- List all blobs --
Get-AzureStorageBlob -Container data -Context $saContext | select Name,BlobType,Length | Format-Table -AutoSize

# -- Open blob --
[System.Diagnostics.Process]::Start("iexplore","https://" + $SAccountName + ".core.windows.net/data/MSFTDXPortugal.jpg")

Get-AzureStorageContainer -Name data -Context $saContext | select Name,PublicAccess | Format-Table -AutoSize


# -- change container permission and access blob -- 
Set-AzureStorageContainerAcl -Name data -Context $saContext -Permission Blob
Get-AzureStorageContainer -Name data -Context $saContext | select Name,PublicAccess | Format-Table -AutoSize

[System.Diagnostics.Process]::Start("iexplore","https://" + $SAccountName + ".blob.core.windows.net/data/MSFTDXPortugal.jpg")


# -- Storage resource usage of the current subscription --
Get-AzureRmStorageUsage

<# 
+----------------------------------------------------------------+
|  Azure Virtual Machine                                         |
+----------------------------------------------------------------+
#>

# -- Starting VM --
Start-AzureRmVM -Name $VMName -ResourceGroupName $AzureLocation

# -- Informacions VM --
Get-AzureRMVM -Name $VMName -ResourceGroupName $AzureLocation | select Name,ResourceGroupName,Location,StatusCode | Ft -AutoSize

# -- Usage Virtual Machine --
AzureRM.Compute\Get-AzureRmVMUsage -Location $AzureLocation -Verbose

# -- Stop VM --
Stop-AzureRmVM -Name $VMName -ResourceGroupName $AzureLocation

<#
+----------------------------------------------------------------+
|  Destroy module 4 demo environment                             |
+----------------------------------------------------------------+
#>
Remove-AzureRmResourceGroup -Name $RGName

